@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/soapbind11.py
 # PyXB bindings for NamespaceModule
 # NSM:2df158009b766a507448a09144cbc02d3d478843
-# Generated 2009-11-30 18:08:42.371080 by PyXB version 1.1.0
+# Generated 2010-05-30 12:40:51.219651 by PyXB version 1.1.2
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +11,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:af24c126-de0d-11de-b04f-001cc05930fc')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7d493f5e-6c12-11df-a28a-001636553c48')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -22,12 +22,12 @@ Namespace.configureCategories(['typeBinding', 'elementBinding'])
 ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
 ModuleRecord._setModule(sys.modules[__name__])
 
-def CreateFromDocument (xml_text, default_namespace=None):
+def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a Python instance."""
     if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
         dom = pyxb.utils.domutils.StringToDOM(xml_text)
         return CreateFromDOM(dom.documentElement)
-    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace())
+    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace(), location_base=location_base)
     handler = saxer.getContentHandler()
     saxer.parse(StringIO.StringIO(xml_text))
     instance = handler.rootObject()
@@ -56,6 +56,19 @@ tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_valu
 tStyleChoice._InitializeFacetMap(tStyleChoice._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'tStyleChoice', tStyleChoice)
 
+# Atomic SimpleTypeDefinition
+class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
+
+    """An atomic simple type."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
+    _Documentation = None
+useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
+useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal')
+useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded')
+useChoice._InitializeFacetMap(useChoice._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
+
 # List SimpleTypeDefinition
 # superclasses pyxb.binding.datatypes.anySimpleType
 class encodingStyle (pyxb.binding.basis.STD_list):
@@ -71,19 +84,6 @@ class encodingStyle (pyxb.binding.basis.STD_list):
 encodingStyle._InitializeFacetMap()
 Namespace.addCategoryObject('typeBinding', u'encodingStyle', encodingStyle)
 
-# Atomic SimpleTypeDefinition
-class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'useChoice')
-    _Documentation = None
-useChoice._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=useChoice, enum_prefix=None)
-useChoice.literal = useChoice._CF_enumeration.addEnumeration(unicode_value=u'literal')
-useChoice.encoded = useChoice._CF_enumeration.addEnumeration(unicode_value=u'encoded')
-useChoice._InitializeFacetMap(useChoice._CF_enumeration)
-Namespace.addCategoryObject('typeBinding', u'useChoice', useChoice)
-
 # Complex type tOperation with content type EMPTY
 class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
@@ -92,11 +92,7 @@ class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tOperation')
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
-    # Attribute soapAction uses Python identifier soapAction
-    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
-    
-    soapAction = property(__soapAction.value, __soapAction.set, None, None)
-
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
     # Attribute style uses Python identifier style
     __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_style', tStyleChoice)
@@ -104,7 +100,11 @@ class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     style = property(__style.value, __style.set, None, None)
 
     
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    # Attribute soapAction uses Python identifier soapAction
+    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
+    
+    soapAction = property(__soapAction.value, __soapAction.set, None, None)
+
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -112,63 +112,12 @@ class tOperation (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
-        __soapAction.name() : __soapAction,
-        __style.name() : __style
+        __style.name() : __style,
+        __soapAction.name() : __soapAction
     })
 Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
 
 
-# Complex type tHeaderFault with content type EMPTY
-class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    part = property(__part.value, __part.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_use', useChoice, required=True)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_encodingStyle', encodingStyle)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        __message.name() : __message,
-        __part.name() : __part,
-        __namespace.name() : __namespace,
-        __use.name() : __use,
-        __encodingStyle.name() : __encodingStyle
-    }
-Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
-
-
 # Complex type tBody with content type EMPTY
 class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
@@ -185,10 +134,10 @@ class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     parts = property(__parts.value, __parts.set, None, None)
 
     
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
     
-    namespace = property(__namespace.value, __namespace.set, None, None)
+    use = property(__use.value, __use.set, None, None)
 
     
     # Attribute encodingStyle uses Python identifier encodingStyle
@@ -197,10 +146,10 @@ class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
     
-    use = property(__use.value, __use.set, None, None)
+    namespace = property(__namespace.value, __namespace.set, None, None)
 
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
@@ -210,9 +159,9 @@ class tBody (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
         __parts.name() : __parts,
-        __namespace.name() : __namespace,
+        __use.name() : __use,
         __encodingStyle.name() : __encodingStyle,
-        __use.name() : __use
+        __namespace.name() : __namespace
     })
 Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
 
@@ -232,10 +181,10 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     headerfault = property(__headerfault.value, __headerfault.set, None, None)
 
     
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_use', useChoice, required=True)
     
-    part = property(__part.value, __part.set, None, None)
+    use = property(__use.value, __use.set, None, None)
 
     
     # Attribute namespace uses Python identifier namespace
@@ -244,24 +193,24 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     namespace = property(__namespace.value, __namespace.set, None, None)
 
     
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_use', useChoice, required=True)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_message', pyxb.binding.datatypes.QName, required=True)
+    
+    message = property(__message.value, __message.set, None, None)
+
+    
     # Attribute encodingStyle uses Python identifier encodingStyle
     __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_encodingStyle', encodingStyle)
     
     encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_message', pyxb.binding.datatypes.QName, required=True)
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeader_part', pyxb.binding.datatypes.NMTOKEN, required=True)
     
-    message = property(__message.value, __message.set, None, None)
+    part = property(__part.value, __part.set, None, None)
 
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
@@ -270,11 +219,11 @@ class tHeader (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
-        __part.name() : __part,
-        __namespace.name() : __namespace,
         __use.name() : __use,
+        __namespace.name() : __namespace,
+        __message.name() : __message,
         __encodingStyle.name() : __encodingStyle,
-        __message.name() : __message
+        __part.name() : __part
     })
 Namespace.addCategoryObject('typeBinding', u'tHeader', tHeader)
 
@@ -287,12 +236,6 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBinding')
     # Base type is pyxb.bundles.wssplat.wsdl11.tExtensibilityElement
     
-    # Attribute style uses Python identifier style
-    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tBinding_style', tStyleChoice)
-    
-    style = property(__style.value, __style.set, None, None)
-
-    
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
     # Attribute transport uses Python identifier transport
@@ -300,6 +243,12 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     
     transport = property(__transport.value, __transport.set, None, None)
 
+    
+    # Attribute style uses Python identifier style
+    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap_tBinding_style', tStyleChoice)
+    
+    style = property(__style.value, __style.set, None, None)
+
 
     _ElementMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._ElementMap.copy()
     _ElementMap.update({
@@ -307,12 +256,161 @@ class tBinding (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     })
     _AttributeMap = pyxb.bundles.wssplat.wsdl11.tExtensibilityElement._AttributeMap.copy()
     _AttributeMap.update({
-        __style.name() : __style,
-        __transport.name() : __transport
+        __transport.name() : __transport,
+        __style.name() : __style
     })
 Namespace.addCategoryObject('typeBinding', u'tBinding', tBinding)
 
 
+# Complex type tHeaderFault with content type EMPTY
+class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
+    
+    part = property(__part.value, __part.set, None, None)
+
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_encodingStyle', encodingStyle)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
+    
+    message = property(__message.value, __message.set, None, None)
+
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_use', useChoice, required=True)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        __part.name() : __part,
+        __encodingStyle.name() : __encodingStyle,
+        __message.name() : __message,
+        __use.name() : __use,
+        __namespace.name() : __namespace
+    }
+Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
+
+
+# Complex type tFaultRes with content type EMPTY
+class tFaultRes (tBody):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = True
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
+    # Base type is tBody
+    
+    # Attribute parts is restricted from parent
+    
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS, prohibited=True)
+    
+    parts = property()
+
+    
+    # Attribute encodingStyle is restricted from parent
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_encodingStyle', encodingStyle)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute required is restricted from parent
+    
+    # Attribute {http://schemas.xmlsoap.org/wsdl/}required uses Python identifier required
+    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://schemas.xmlsoap.org/wsdl/'), u'required'), 'required', '__httpschemas_xmlsoap_orgwsdl_tExtensibilityElement_httpschemas_xmlsoap_orgwsdlrequired', pyxb.binding.datatypes.boolean)
+    
+    required = property(__required.value, __required.set, None, None)
+
+    
+    # Attribute use is restricted from parent
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute namespace is restricted from parent
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+
+    _ElementMap = tBody._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = tBody._AttributeMap.copy()
+    _AttributeMap.update({
+        __parts.name() : __parts,
+        __encodingStyle.name() : __encodingStyle,
+        __required.name() : __required,
+        __use.name() : __use,
+        __namespace.name() : __namespace
+    })
+Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
+
+
+# Complex type tFault with content type EMPTY
+class tFault (tFaultRes):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFault')
+    # Base type is tFaultRes
+    
+    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap_tFault_name', pyxb.binding.datatypes.NCName, required=True)
+    
+    name = property(__name.value, __name.set, None, None)
+
+    
+    # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    
+    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    
+    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+    
+    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
+
+    _ElementMap = tFaultRes._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = tFaultRes._AttributeMap.copy()
+    _AttributeMap.update({
+        __name.name() : __name
+    })
+Namespace.addCategoryObject('typeBinding', u'tFault', tFault)
+
+
 # Complex type tAddress with content type EMPTY
 class tAddress (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
@@ -340,110 +438,9 @@ class tAddress (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
 Namespace.addCategoryObject('typeBinding', u'tAddress', tAddress)
 
 
-# Complex type tFaultRes with content type EMPTY
-class tFaultRes (tBody):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = True
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
-    # Base type is tBody
-    
-    # Attribute required is restricted from parent
-    
-    # Attribute {http://schemas.xmlsoap.org/wsdl/}required uses Python identifier required
-    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(Namespace, u'required'), 'required', '__httpschemas_xmlsoap_orgwsdl_tExtensibilityElement_httpschemas_xmlsoap_orgwsdlrequired', pyxb.binding.datatypes.boolean)
-    
-    required = property(__required.value, __required.set, None, None)
-
-    
-    # Attribute parts is restricted from parent
-    
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_parts', pyxb.binding.datatypes.NMTOKENS, prohibited=True)
-    
-    parts = property()
-
-    
-    # Attribute use is restricted from parent
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_use', useChoice)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    
-    # Attribute encodingStyle is restricted from parent
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_encodingStyle', encodingStyle)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute namespace is restricted from parent
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap_tBody_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-
-    _ElementMap = tBody._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = tBody._AttributeMap.copy()
-    _AttributeMap.update({
-        __required.name() : __required,
-        __parts.name() : __parts,
-        __use.name() : __use,
-        __encodingStyle.name() : __encodingStyle,
-        __namespace.name() : __namespace
-    })
-Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
-
-
-# Complex type tFault with content type EMPTY
-class tFault (tFaultRes):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFault')
-    # Base type is tFaultRes
-    
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap_tFault_name', pyxb.binding.datatypes.NCName, required=True)
-    
-    name = property(__name.value, __name.set, None, None)
-
-    
-    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-    
-    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-    
-    # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-    
-    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-    
-    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap/}tFaultRes
-
-    _ElementMap = tFaultRes._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = tFaultRes._AttributeMap.copy()
-    _AttributeMap.update({
-        __name.name() : __name
-    })
-Namespace.addCategoryObject('typeBinding', u'tFault', tFault)
-
-
 operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), tOperation)
 Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
-headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
-Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
-
 body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
 Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
 
@@ -453,17 +450,19 @@ Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), tBinding)
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
-address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), tAddress)
-Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
+headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
+Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
 
 fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'fault'), tFault)
 Namespace.addCategoryObject('elementBinding', fault.name().localName(), fault)
 
+address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), tAddress)
+Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
+
 
 
 tHeader._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault, scope=tHeader))
-tHeader._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=tHeader._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'headerfault'))),
-    ])
-})
+tHeader._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(tHeader._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'headerfault')), min_occurs=0L, max_occurs=None)
+    )
+tHeader._ContentModel = pyxb.binding.content.ParticleModel(tHeader._GroupModel, min_occurs=1, max_occurs=1)
