@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/soapbind12.py
 # PyXB bindings for NamespaceModule
 # NSM:fe6dee6f975d5202c12c3e364c8df804f68deab8
-# Generated 2009-11-30 18:08:43.208273 by PyXB version 1.1.0
+# Generated 2010-05-30 12:40:51.717034 by PyXB version 1.1.2
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +11,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:afa52618-de0d-11de-bc6d-001cc05930fc')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7d94b114-6c12-11df-981d-001636553c48')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -22,12 +22,12 @@ Namespace.configureCategories(['typeBinding', 'elementBinding'])
 ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
 ModuleRecord._setModule(sys.modules[__name__])
 
-def CreateFromDocument (xml_text, default_namespace=None):
+def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a Python instance."""
     if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
         dom = pyxb.utils.domutils.StringToDOM(xml_text)
         return CreateFromDOM(dom.documentElement)
-    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace())
+    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace(), location_base=location_base)
     handler = saxer.getContentHandler()
     saxer.parse(StringIO.StringIO(xml_text))
     instance = handler.rootObject()
@@ -43,6 +43,19 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
+# List SimpleTypeDefinition
+# superclasses pyxb.binding.datatypes.anySimpleType
+class tParts (pyxb.binding.basis.STD_list):
+
+    """Simple type that is a list of pyxb.binding.datatypes.NMTOKEN."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tParts')
+    _Documentation = None
+
+    _ItemType = pyxb.binding.datatypes.NMTOKEN
+tParts._InitializeFacetMap()
+Namespace.addCategoryObject('typeBinding', u'tParts', tParts)
+
 # Atomic SimpleTypeDefinition
 class useChoice (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):
 
@@ -69,71 +82,6 @@ tStyleChoice.document = tStyleChoice._CF_enumeration.addEnumeration(unicode_valu
 tStyleChoice._InitializeFacetMap(tStyleChoice._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'tStyleChoice', tStyleChoice)
 
-# List SimpleTypeDefinition
-# superclasses pyxb.binding.datatypes.anySimpleType
-class tParts (pyxb.binding.basis.STD_list):
-
-    """Simple type that is a list of pyxb.binding.datatypes.NMTOKEN."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tParts')
-    _Documentation = None
-
-    _ItemType = pyxb.binding.datatypes.NMTOKEN
-tParts._InitializeFacetMap()
-Namespace.addCategoryObject('typeBinding', u'tParts', tParts)
-
-# Complex type tHeaderFault with content type EMPTY
-class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
-    # Attribute part uses Python identifier part
-    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
-    
-    part = property(__part.value, __part.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_use', useChoice, required=True)
-    
-    use = property(__use.value, __use.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        __message.name() : __message,
-        __part.name() : __part,
-        __encodingStyle.name() : __encodingStyle,
-        __namespace.name() : __namespace,
-        __use.name() : __use
-    }
-Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
-
-
 # Complex type tExtensibilityElementOpenAttrs with content type EMPTY
 class tExtensibilityElementOpenAttrs (pyxb.bundles.wssplat.wsdl11.tExtensibilityElement):
     _TypeDefinition = None
@@ -156,6 +104,153 @@ class tExtensibilityElementOpenAttrs (pyxb.bundles.wssplat.wsdl11.tExtensibility
 Namespace.addCategoryObject('typeBinding', u'tExtensibilityElementOpenAttrs', tExtensibilityElementOpenAttrs)
 
 
+# Complex type tBody with content type EMPTY
+class tBody (tExtensibilityElementOpenAttrs):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBody')
+    # Base type is tExtensibilityElementOpenAttrs
+    
+    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts)
+    
+    parts = property(__parts.value, __parts.set, None, None)
+
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
+
+    _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
+    _AttributeMap.update({
+        __parts.name() : __parts,
+        __use.name() : __use,
+        __namespace.name() : __namespace,
+        __encodingStyle.name() : __encodingStyle
+    })
+Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
+
+
+# Complex type tFaultRes with content type EMPTY
+class tFaultRes (tBody):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = True
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
+    # Base type is tBody
+    
+    # Attribute required is restricted from parent
+    
+    # Attribute {http://schemas.xmlsoap.org/wsdl/}required uses Python identifier required
+    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://schemas.xmlsoap.org/wsdl/'), u'required'), 'required', '__httpschemas_xmlsoap_orgwsdl_tExtensibilityElement_httpschemas_xmlsoap_orgwsdlrequired', pyxb.binding.datatypes.boolean)
+    
+    required = property(__required.value, __required.set, None, None)
+
+    
+    # Attribute parts is restricted from parent
+    
+    # Attribute parts uses Python identifier parts
+    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts, prohibited=True)
+    
+    parts = property()
+
+    
+    # Attribute encodingStyle is restricted from parent
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
+    
+    # Attribute use is restricted from parent
+    
+    # Attribute use uses Python identifier use
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
+    
+    use = property(__use.value, __use.set, None, None)
+
+    
+    # Attribute namespace is restricted from parent
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+
+    _ElementMap = tBody._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = tBody._AttributeMap.copy()
+    _AttributeMap.update({
+        __required.name() : __required,
+        __parts.name() : __parts,
+        __encodingStyle.name() : __encodingStyle,
+        __use.name() : __use,
+        __namespace.name() : __namespace
+    })
+Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
+
+
+# Complex type tFault with content type EMPTY
+class tFault (tFaultRes):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFault')
+    # Base type is tFaultRes
+    
+    # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap12_tFault_name', pyxb.binding.datatypes.NCName, required=True)
+    
+    name = property(__name.value, __name.set, None, None)
+
+    
+    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
+    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
+    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+    
+    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
+
+    _ElementMap = tFaultRes._ElementMap.copy()
+    _ElementMap.update({
+        
+    })
+    _AttributeMap = tFaultRes._AttributeMap.copy()
+    _AttributeMap.update({
+        __name.name() : __name
+    })
+Namespace.addCategoryObject('typeBinding', u'tFault', tFault)
+
+
 # Complex type tAddress with content type EMPTY
 class tAddress (tExtensibilityElementOpenAttrs):
     _TypeDefinition = None
@@ -192,14 +287,6 @@ class tOperation (tExtensibilityElementOpenAttrs):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tOperation')
     # Base type is tExtensibilityElementOpenAttrs
     
-    # Attribute soapAction uses Python identifier soapAction
-    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
-    
-    soapAction = property(__soapAction.value, __soapAction.set, None, None)
-
-    
-    # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
-    
     # Attribute soapActionRequired uses Python identifier soapActionRequired
     __soapActionRequired = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapActionRequired'), 'soapActionRequired', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapActionRequired', pyxb.binding.datatypes.boolean)
     
@@ -211,53 +298,13 @@ class tOperation (tExtensibilityElementOpenAttrs):
     
     style = property(__style.value, __style.set, None, None)
 
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
-
-    _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
-    _AttributeMap.update({
-        __soapAction.name() : __soapAction,
-        __soapActionRequired.name() : __soapActionRequired,
-        __style.name() : __style
-    })
-Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
-
-
-# Complex type tBody with content type EMPTY
-class tBody (tExtensibilityElementOpenAttrs):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBody')
-    # Base type is tExtensibilityElementOpenAttrs
     
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts)
+    # Attribute soapAction uses Python identifier soapAction
+    __soapAction = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'soapAction'), 'soapAction', '__httpschemas_xmlsoap_orgwsdlsoap12_tOperation_soapAction', pyxb.binding.datatypes.anyURI)
     
-    parts = property(__parts.value, __parts.set, None, None)
-
-    
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
-
-    
-    # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
-    
-    use = property(__use.value, __use.set, None, None)
+    soapAction = property(__soapAction.value, __soapAction.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
@@ -267,12 +314,11 @@ class tBody (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
-        __parts.name() : __parts,
-        __namespace.name() : __namespace,
-        __encodingStyle.name() : __encodingStyle,
-        __use.name() : __use
+        __soapActionRequired.name() : __soapActionRequired,
+        __style.name() : __style,
+        __soapAction.name() : __soapAction
     })
-Namespace.addCategoryObject('typeBinding', u'tBody', tBody)
+Namespace.addCategoryObject('typeBinding', u'tOperation', tOperation)
 
 
 # Complex type tHeader with content type ELEMENT_ONLY
@@ -290,16 +336,10 @@ class tHeader (tExtensibilityElementOpenAttrs):
     headerfault = property(__headerfault.value, __headerfault.set, None, None)
 
     
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_namespace', pyxb.binding.datatypes.anyURI)
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_message', pyxb.binding.datatypes.QName, required=True)
     
-    namespace = property(__namespace.value, __namespace.set, None, None)
-
-    
-    # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_encodingStyle', pyxb.binding.datatypes.anyURI)
-    
-    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+    message = property(__message.value, __message.set, None, None)
 
     
     # Attribute part uses Python identifier part
@@ -308,19 +348,25 @@ class tHeader (tExtensibilityElementOpenAttrs):
     part = property(__part.value, __part.set, None, None)
 
     
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
+
+    
     # Attribute use uses Python identifier use
     __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_use', useChoice, required=True)
     
     use = property(__use.value, __use.set, None, None)
 
     
-    # Attribute message uses Python identifier message
-    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_message', pyxb.binding.datatypes.QName, required=True)
-    
-    message = property(__message.value, __message.set, None, None)
-
-    
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
+    
+    # Attribute encodingStyle uses Python identifier encodingStyle
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeader_encodingStyle', pyxb.binding.datatypes.anyURI)
+    
+    encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
     _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
@@ -329,111 +375,65 @@ class tHeader (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
-        __namespace.name() : __namespace,
-        __encodingStyle.name() : __encodingStyle,
+        __message.name() : __message,
         __part.name() : __part,
+        __namespace.name() : __namespace,
         __use.name() : __use,
-        __message.name() : __message
+        __encodingStyle.name() : __encodingStyle
     })
 Namespace.addCategoryObject('typeBinding', u'tHeader', tHeader)
 
 
-# Complex type tFaultRes with content type EMPTY
-class tFaultRes (tBody):
+# Complex type tHeaderFault with content type EMPTY
+class tHeaderFault (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = True
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFaultRes')
-    # Base type is tBody
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tHeaderFault')
+    # Base type is pyxb.binding.datatypes.anyType
     
-    # Attribute required is restricted from parent
+    # Attribute part uses Python identifier part
+    __part = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'part'), 'part', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_part', pyxb.binding.datatypes.NMTOKEN, required=True)
     
-    # Attribute {http://schemas.xmlsoap.org/wsdl/}required uses Python identifier required
-    __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(Namespace, u'required'), 'required', '__httpschemas_xmlsoap_orgwsdl_tExtensibilityElement_httpschemas_xmlsoap_orgwsdlrequired', pyxb.binding.datatypes.boolean)
-    
-    required = property(__required.value, __required.set, None, None)
+    part = property(__part.value, __part.set, None, None)
 
     
-    # Attribute parts is restricted from parent
-    
-    # Attribute parts uses Python identifier parts
-    __parts = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parts'), 'parts', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_parts', tParts, prohibited=True)
-    
-    parts = property()
-
-    
-    # Attribute encodingStyle is restricted from parent
-    
     # Attribute encodingStyle uses Python identifier encodingStyle
-    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_encodingStyle', pyxb.binding.datatypes.anyURI)
+    __encodingStyle = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'encodingStyle'), 'encodingStyle', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_encodingStyle', pyxb.binding.datatypes.anyURI)
     
     encodingStyle = property(__encodingStyle.value, __encodingStyle.set, None, None)
 
     
-    # Attribute namespace is restricted from parent
+    # Attribute message uses Python identifier message
+    __message = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'message'), 'message', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_message', pyxb.binding.datatypes.QName, required=True)
     
-    # Attribute namespace uses Python identifier namespace
-    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_namespace', pyxb.binding.datatypes.anyURI)
-    
-    namespace = property(__namespace.value, __namespace.set, None, None)
+    message = property(__message.value, __message.set, None, None)
 
     
-    # Attribute use is restricted from parent
-    
     # Attribute use uses Python identifier use
-    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tBody_use', useChoice)
+    __use = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'use'), 'use', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_use', useChoice, required=True)
     
     use = property(__use.value, __use.set, None, None)
 
+    
+    # Attribute namespace uses Python identifier namespace
+    __namespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'namespace'), 'namespace', '__httpschemas_xmlsoap_orgwsdlsoap12_tHeaderFault_namespace', pyxb.binding.datatypes.anyURI)
+    
+    namespace = property(__namespace.value, __namespace.set, None, None)
 
-    _ElementMap = tBody._ElementMap.copy()
-    _ElementMap.update({
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
+
+    _ElementMap = {
         
-    })
-    _AttributeMap = tBody._AttributeMap.copy()
-    _AttributeMap.update({
-        __required.name() : __required,
-        __parts.name() : __parts,
+    }
+    _AttributeMap = {
+        __part.name() : __part,
         __encodingStyle.name() : __encodingStyle,
-        __namespace.name() : __namespace,
-        __use.name() : __use
-    })
-Namespace.addCategoryObject('typeBinding', u'tFaultRes', tFaultRes)
-
-
-# Complex type tFault with content type EMPTY
-class tFault (tFaultRes):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tFault')
-    # Base type is tFaultRes
-    
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpschemas_xmlsoap_orgwsdlsoap12_tFault_name', pyxb.binding.datatypes.NCName, required=True)
-    
-    name = property(__name.value, __name.set, None, None)
-
-    
-    # Attribute encodingStyle_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
-    # Attribute required_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
-    # Attribute namespace_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
-    # Attribute parts_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-    
-    # Attribute use_ inherited from {http://schemas.xmlsoap.org/wsdl/soap12/}tFaultRes
-
-    _ElementMap = tFaultRes._ElementMap.copy()
-    _ElementMap.update({
-        
-    })
-    _AttributeMap = tFaultRes._AttributeMap.copy()
-    _AttributeMap.update({
-        __name.name() : __name
-    })
-Namespace.addCategoryObject('typeBinding', u'tFault', tFault)
+        __message.name() : __message,
+        __use.name() : __use,
+        __namespace.name() : __namespace
+    }
+Namespace.addCategoryObject('typeBinding', u'tHeaderFault', tHeaderFault)
 
 
 # Complex type tBinding with content type EMPTY
@@ -444,12 +444,6 @@ class tBinding (tExtensibilityElementOpenAttrs):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'tBinding')
     # Base type is tExtensibilityElementOpenAttrs
     
-    # Attribute style uses Python identifier style
-    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap12_tBinding_style', tStyleChoice)
-    
-    style = property(__style.value, __style.set, None, None)
-
-    
     # Attribute required inherited from {http://schemas.xmlsoap.org/wsdl/}tExtensibilityElement
     
     # Attribute transport uses Python identifier transport
@@ -457,6 +451,12 @@ class tBinding (tExtensibilityElementOpenAttrs):
     
     transport = property(__transport.value, __transport.set, None, None)
 
+    
+    # Attribute style uses Python identifier style
+    __style = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'style'), 'style', '__httpschemas_xmlsoap_orgwsdlsoap12_tBinding_style', tStyleChoice)
+    
+    style = property(__style.value, __style.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/wsdl/soap12/'))
 
     _ElementMap = tExtensibilityElementOpenAttrs._ElementMap.copy()
@@ -465,14 +465,14 @@ class tBinding (tExtensibilityElementOpenAttrs):
     })
     _AttributeMap = tExtensibilityElementOpenAttrs._AttributeMap.copy()
     _AttributeMap.update({
-        __style.name() : __style,
-        __transport.name() : __transport
+        __transport.name() : __transport,
+        __style.name() : __style
     })
 Namespace.addCategoryObject('typeBinding', u'tBinding', tBinding)
 
 
-headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
-Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
+fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'fault'), tFault)
+Namespace.addCategoryObject('elementBinding', fault.name().localName(), fault)
 
 address = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'address'), tAddress)
 Namespace.addCategoryObject('elementBinding', address.name().localName(), address)
@@ -480,23 +480,22 @@ Namespace.addCategoryObject('elementBinding', address.name().localName(), addres
 operation = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'operation'), tOperation)
 Namespace.addCategoryObject('elementBinding', operation.name().localName(), operation)
 
-body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
-Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
-
 header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), tHeader)
 Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 
-fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'fault'), tFault)
-Namespace.addCategoryObject('elementBinding', fault.name().localName(), fault)
+body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'body'), tBody)
+Namespace.addCategoryObject('elementBinding', body.name().localName(), body)
 
 binding = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'binding'), tBinding)
 Namespace.addCategoryObject('elementBinding', binding.name().localName(), binding)
 
+headerfault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault)
+Namespace.addCategoryObject('elementBinding', headerfault.name().localName(), headerfault)
+
 
 
 tHeader._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'headerfault'), tHeaderFault, scope=tHeader))
-tHeader._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=tHeader._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'headerfault'))),
-    ])
-})
+tHeader._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(tHeader._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'headerfault')), min_occurs=0L, max_occurs=None)
+    )
+tHeader._ContentModel = pyxb.binding.content.ParticleModel(tHeader._GroupModel, min_occurs=1, max_occurs=1)
