@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsa.py
 # PyXB bindings for NamespaceModule
 # NSM:0ecbd27a42302a2dbf33a51269e14ce6419c0738
-# Generated 2009-11-30 18:08:50.143182 by PyXB version 1.1.0
+# Generated 2010-05-30 12:40:56.018478 by PyXB version 1.1.2
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +11,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:b3ce0746-de0d-11de-80f6-001cc05930fc')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:80284bfc-6c12-11df-b492-001636553c48')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -21,12 +21,12 @@ Namespace.configureCategories(['typeBinding', 'elementBinding'])
 ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
 ModuleRecord._setModule(sys.modules[__name__])
 
-def CreateFromDocument (xml_text, default_namespace=None):
+def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a Python instance."""
     if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
         dom = pyxb.utils.domutils.StringToDOM(xml_text)
         return CreateFromDOM(dom.documentElement)
-    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace())
+    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace(), location_base=location_base)
     handler = saxer.getContentHandler()
     saxer.parse(StringIO.StringIO(xml_text))
     instance = handler.rootObject()
@@ -64,11 +64,11 @@ class RelationshipTypeOpenEnum (pyxb.binding.basis.STD_union):
     _Documentation = None
 
     _MemberTypes = ( RelationshipType, pyxb.binding.datatypes.anyURI, )
-RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
 RelationshipTypeOpenEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipTypeOpenEnum)
+RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
 RelationshipTypeOpenEnum.httpwww_w3_org200508addressingreply = u'http://www.w3.org/2005/08/addressing/reply'# originally RelationshipType.httpwww_w3_org200508addressingreply
-RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_pattern,
-   RelationshipTypeOpenEnum._CF_enumeration)
+RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_enumeration,
+   RelationshipTypeOpenEnum._CF_pattern)
 Namespace.addCategoryObject('typeBinding', u'RelationshipTypeOpenEnum', RelationshipTypeOpenEnum)
 
 # Atomic SimpleTypeDefinition
@@ -103,8 +103,8 @@ class FaultCodesOpenEnumType (pyxb.binding.basis.STD_union):
     _Documentation = None
 
     _MemberTypes = ( FaultCodesType, pyxb.binding.datatypes.QName, )
-FaultCodesOpenEnumType._CF_pattern = pyxb.binding.facets.CF_pattern()
 FaultCodesOpenEnumType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesOpenEnumType)
+FaultCodesOpenEnumType._CF_pattern = pyxb.binding.facets.CF_pattern()
 FaultCodesOpenEnumType.tnsInvalidAddressingHeader = u'tns:InvalidAddressingHeader'# originally FaultCodesType.tnsInvalidAddressingHeader
 FaultCodesOpenEnumType.tnsInvalidAddress = u'tns:InvalidAddress'# originally FaultCodesType.tnsInvalidAddress
 FaultCodesOpenEnumType.tnsInvalidEPR = u'tns:InvalidEPR'# originally FaultCodesType.tnsInvalidEPR
@@ -116,10 +116,61 @@ FaultCodesOpenEnumType.tnsMessageAddressingHeaderRequired = u'tns:MessageAddress
 FaultCodesOpenEnumType.tnsDestinationUnreachable = u'tns:DestinationUnreachable'# originally FaultCodesType.tnsDestinationUnreachable
 FaultCodesOpenEnumType.tnsActionNotSupported = u'tns:ActionNotSupported'# originally FaultCodesType.tnsActionNotSupported
 FaultCodesOpenEnumType.tnsEndpointUnavailable = u'tns:EndpointUnavailable'# originally FaultCodesType.tnsEndpointUnavailable
-FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_pattern,
-   FaultCodesOpenEnumType._CF_enumeration)
+FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_enumeration,
+   FaultCodesOpenEnumType._CF_pattern)
 Namespace.addCategoryObject('typeBinding', u'FaultCodesOpenEnumType', FaultCodesOpenEnumType)
 
+# Complex type AttributedQNameType with content type SIMPLE
+class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = pyxb.binding.datatypes.QName
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
+    # Base type is pyxb.binding.datatypes.QName
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
+
+
+# Complex type ProblemActionType with content type ELEMENT_ONLY
+class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ProblemActionType')
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Element {http://www.w3.org/2005/08/addressing}Action uses Python identifier Action
+    __Action = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Action'), 'Action', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingAction', False)
+
+    
+    Action = property(__Action.value, __Action.set, None, None)
+
+    
+    # Element {http://www.w3.org/2005/08/addressing}SoapAction uses Python identifier SoapAction
+    __SoapAction = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), 'SoapAction', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingSoapAction', False)
+
+    
+    SoapAction = property(__SoapAction.value, __SoapAction.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+
+    _ElementMap = {
+        __Action.name() : __Action,
+        __SoapAction.name() : __SoapAction
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'ProblemActionType', ProblemActionType)
+
+
 # Complex type RelatesToType with content type SIMPLE
 class RelatesToType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = pyxb.binding.datatypes.anyURI
@@ -144,25 +195,6 @@ class RelatesToType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'RelatesToType', RelatesToType)
 
 
-# Complex type MetadataType with content type ELEMENT_ONLY
-class MetadataType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'MetadataType')
-    # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'MetadataType', MetadataType)
-
-
 # Complex type AttributedURIType with content type SIMPLE
 class AttributedURIType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = pyxb.binding.datatypes.anyURI
@@ -241,14 +273,15 @@ class EndpointReferenceType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'EndpointReferenceType', EndpointReferenceType)
 
 
-# Complex type AttributedQNameType with content type SIMPLE
-class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.QName
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+# Complex type MetadataType with content type ELEMENT_ONLY
+class MetadataType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
-    # Base type is pyxb.binding.datatypes.QName
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'MetadataType')
+    # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+    _HasWildcardElement = True
 
     _ElementMap = {
         
@@ -256,7 +289,7 @@ class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap = {
         
     }
-Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
+Namespace.addCategoryObject('typeBinding', u'MetadataType', MetadataType)
 
 
 # Complex type ReferenceParametersType with content type ELEMENT_ONLY
@@ -278,75 +311,42 @@ class ReferenceParametersType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'ReferenceParametersType', ReferenceParametersType)
 
 
-# Complex type ProblemActionType with content type ELEMENT_ONLY
-class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ProblemActionType')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Element {http://www.w3.org/2005/08/addressing}SoapAction uses Python identifier SoapAction
-    __SoapAction = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), 'SoapAction', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingSoapAction', False)
-
-    
-    SoapAction = property(__SoapAction.value, __SoapAction.set, None, None)
-
-    
-    # Element {http://www.w3.org/2005/08/addressing}Action uses Python identifier Action
-    __Action = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Action'), 'Action', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingAction', False)
-
-    
-    Action = property(__Action.value, __Action.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-
-    _ElementMap = {
-        __SoapAction.name() : __SoapAction,
-        __Action.name() : __Action
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'ProblemActionType', ProblemActionType)
-
-
-RelatesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RelatesTo'), RelatesToType)
-Namespace.addCategoryObject('elementBinding', RelatesTo.name().localName(), RelatesTo)
-
-MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'MessageID'), AttributedURIType)
-Namespace.addCategoryObject('elementBinding', MessageID.name().localName(), MessageID)
-
-RetryAfter = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RetryAfter'), AttributedUnsignedLongType)
-Namespace.addCategoryObject('elementBinding', RetryAfter.name().localName(), RetryAfter)
-
-FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'FaultTo'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', FaultTo.name().localName(), FaultTo)
-
 ProblemHeaderQName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemHeaderQName'), AttributedQNameType)
 Namespace.addCategoryObject('elementBinding', ProblemHeaderQName.name().localName(), ProblemHeaderQName)
 
-ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType)
-Namespace.addCategoryObject('elementBinding', ReferenceParameters.name().localName(), ReferenceParameters)
-
-EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'EndpointReference'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', EndpointReference.name().localName(), EndpointReference)
-
 ProblemAction = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemAction'), ProblemActionType)
 Namespace.addCategoryObject('elementBinding', ProblemAction.name().localName(), ProblemAction)
 
-ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReplyTo'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', ReplyTo.name().localName(), ReplyTo)
+RelatesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RelatesTo'), RelatesToType)
+Namespace.addCategoryObject('elementBinding', RelatesTo.name().localName(), RelatesTo)
 
-From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'From'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', From.name().localName(), From)
+RetryAfter = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RetryAfter'), AttributedUnsignedLongType)
+Namespace.addCategoryObject('elementBinding', RetryAfter.name().localName(), RetryAfter)
+
+MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'MessageID'), AttributedURIType)
+Namespace.addCategoryObject('elementBinding', MessageID.name().localName(), MessageID)
+
+EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'EndpointReference'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', EndpointReference.name().localName(), EndpointReference)
 
 ProblemIRI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemIRI'), AttributedURIType)
 Namespace.addCategoryObject('elementBinding', ProblemIRI.name().localName(), ProblemIRI)
 
+FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'FaultTo'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', FaultTo.name().localName(), FaultTo)
+
 Metadata = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType)
 Namespace.addCategoryObject('elementBinding', Metadata.name().localName(), Metadata)
 
+ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType)
+Namespace.addCategoryObject('elementBinding', ReferenceParameters.name().localName(), ReferenceParameters)
+
+From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'From'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', From.name().localName(), From)
+
+ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReplyTo'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', ReplyTo.name().localName(), ReplyTo)
+
 To = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'To'), AttributedURIType)
 Namespace.addCategoryObject('elementBinding', To.name().localName(), To)
 
@@ -354,11 +354,15 @@ Action = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Act
 Namespace.addCategoryObject('elementBinding', Action.name().localName(), Action)
 
 
-MetadataType._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)),
-    ])
-})
+
+ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Action'), AttributedURIType, scope=ProblemActionType))
+
+ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), pyxb.binding.datatypes.anyURI, scope=ProblemActionType))
+ProblemActionType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Action')), min_occurs=0L, max_occurs=1),
+    pyxb.binding.content.ParticleModel(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'SoapAction')), min_occurs=0L, max_occurs=1)
+    )
+ProblemActionType._ContentModel = pyxb.binding.content.ParticleModel(ProblemActionType._GroupModel, min_occurs=1, max_occurs=1)
 
 
 
@@ -367,44 +371,22 @@ EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.Expa
 EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType, scope=EndpointReferenceType))
 
 EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType, scope=EndpointReferenceType))
-EndpointReferenceType._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=False, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=3, element_use=EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Address'))),
-    ])
-    , 2 : pyxb.binding.content.ContentModelState(state=2, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))),
-    ])
-    , 3 : pyxb.binding.content.ContentModelState(state=3, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, element_use=EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Metadata'))),
-        pyxb.binding.content.ContentModelTransition(next_state=4, element_use=EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'))),
-        pyxb.binding.content.ContentModelTransition(next_state=2, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))),
-    ])
-    , 4 : pyxb.binding.content.ContentModelState(state=4, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, element_use=EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Metadata'))),
-        pyxb.binding.content.ContentModelTransition(next_state=2, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))),
-    ])
-})
+EndpointReferenceType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Address')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters')), min_occurs=0L, max_occurs=1),
+    pyxb.binding.content.ParticleModel(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Metadata')), min_occurs=0L, max_occurs=1),
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing')), min_occurs=0L, max_occurs=None)
+    )
+EndpointReferenceType._ContentModel = pyxb.binding.content.ParticleModel(EndpointReferenceType._GroupModel, min_occurs=1, max_occurs=1)
 
 
-ReferenceParametersType._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)),
-    ])
-})
+MetadataType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+MetadataType._ContentModel = pyxb.binding.content.ParticleModel(MetadataType._GroupModel, min_occurs=1, max_occurs=1)
 
 
-
-ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), pyxb.binding.datatypes.anyURI, scope=ProblemActionType))
-
-ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Action'), AttributedURIType, scope=ProblemActionType))
-ProblemActionType._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, element_use=ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Action'))),
-        pyxb.binding.content.ContentModelTransition(next_state=3, element_use=ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'))),
-    ])
-    , 2 : pyxb.binding.content.ContentModelState(state=2, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=3, element_use=ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'))),
-    ])
-    , 3 : pyxb.binding.content.ContentModelState(state=3, is_final=True, transitions=[
-    ])
-})
+ReferenceParametersType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+ReferenceParametersType._ContentModel = pyxb.binding.content.ParticleModel(ReferenceParametersType._GroupModel, min_occurs=1, max_occurs=1)
