@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsp.py
 # PyXB bindings for NamespaceModule
 # NSM:f4837f0658228740211c38471cfc1510d0fdb629
-# Generated 2009-11-30 18:08:48.564744 by PyXB version 1.1.0
+# Generated 2010-05-30 12:40:55.029672 by PyXB version 1.1.2
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
@@ -11,7 +11,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:b2b7831e-de0d-11de-9df5-001cc05930fc')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:7f92a016-6c12-11df-8bdb-001636553c48')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -21,12 +21,12 @@ Namespace.configureCategories(['typeBinding', 'elementBinding'])
 ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
 ModuleRecord._setModule(sys.modules[__name__])
 
-def CreateFromDocument (xml_text, default_namespace=None):
+def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a Python instance."""
     if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
         dom = pyxb.utils.domutils.StringToDOM(xml_text)
         return CreateFromDOM(dom.documentElement)
-    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace())
+    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=Namespace.fallbackNamespace(), location_base=location_base)
     handler = saxer.getContentHandler()
     saxer.parse(StringIO.StringIO(xml_text))
     instance = handler.rootObject()
@@ -44,7 +44,7 @@ def CreateFromDOM (node, default_namespace=None):
 
 # List SimpleTypeDefinition
 # superclasses pyxb.binding.datatypes.anySimpleType
-class STD_ANON_1 (pyxb.binding.basis.STD_list):
+class STD_ANON (pyxb.binding.basis.STD_list):
 
     """Simple type that is a list of pyxb.binding.datatypes.anyURI."""
 
@@ -52,30 +52,72 @@ class STD_ANON_1 (pyxb.binding.basis.STD_list):
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.anyURI
-STD_ANON_1._InitializeFacetMap()
+STD_ANON._InitializeFacetMap()
 
-# Complex type CTD_ANON_1 with content type ELEMENT_ONLY
-class CTD_ANON_1 (pyxb.binding.basis.complexTypeDefinition):
+# Complex type CTD_ANON with content type ELEMENT_ONLY
+class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
     # Base type is pyxb.binding.datatypes.anyType
     
-    # Attribute DigestAlgorithm uses Python identifier DigestAlgorithm
-    __DigestAlgorithm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'DigestAlgorithm'), 'DigestAlgorithm', '__httpwww_w3_orgnsws_policy_CTD_ANON_1_DigestAlgorithm', pyxb.binding.datatypes.anyURI, unicode_default=u'http://www.w3.org/ns/ws-policy/Sha1Exc')
-    
-    DigestAlgorithm = property(__DigestAlgorithm.value, __DigestAlgorithm.set, None, None)
+    # Element {http://www.w3.org/ns/ws-policy}Policy uses Python identifier Policy
+    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_orgnsws_policy_CTD_ANON_httpwww_w3_orgnsws_policyPolicy', True)
 
     
+    Policy = property(__Policy.value, __Policy.set, None, None)
+
+    
+    # Element {http://www.w3.org/ns/ws-policy}AppliesTo uses Python identifier AppliesTo
+    __AppliesTo = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_orgnsws_policy_CTD_ANON_httpwww_w3_orgnsws_policyAppliesTo', False)
+
+    
+    AppliesTo = property(__AppliesTo.value, __AppliesTo.set, None, None)
+
+    
+    # Element {http://www.w3.org/ns/ws-policy}PolicyReference uses Python identifier PolicyReference
+    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_orgnsws_policy_CTD_ANON_httpwww_w3_orgnsws_policyPolicyReference', True)
+
+    
+    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        __Policy.name() : __Policy,
+        __AppliesTo.name() : __AppliesTo,
+        __PolicyReference.name() : __PolicyReference
+    }
+    _AttributeMap = {
+        
+    }
+
+
+
+# Complex type CTD_ANON_ with content type ELEMENT_ONLY
+class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = None
+    # Base type is pyxb.binding.datatypes.anyType
+    
     # Attribute URI uses Python identifier URI
-    __URI = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'URI'), 'URI', '__httpwww_w3_orgnsws_policy_CTD_ANON_1_URI', pyxb.binding.datatypes.anyURI, required=True)
+    __URI = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'URI'), 'URI', '__httpwww_w3_orgnsws_policy_CTD_ANON__URI', pyxb.binding.datatypes.anyURI, required=True)
     
     URI = property(__URI.value, __URI.set, None, None)
 
     
+    # Attribute DigestAlgorithm uses Python identifier DigestAlgorithm
+    __DigestAlgorithm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'DigestAlgorithm'), 'DigestAlgorithm', '__httpwww_w3_orgnsws_policy_CTD_ANON__DigestAlgorithm', pyxb.binding.datatypes.anyURI, unicode_default=u'http://www.w3.org/ns/ws-policy/Sha1Exc')
+    
+    DigestAlgorithm = property(__DigestAlgorithm.value, __DigestAlgorithm.set, None, None)
+
+    
     # Attribute Digest uses Python identifier Digest
-    __Digest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Digest'), 'Digest', '__httpwww_w3_orgnsws_policy_CTD_ANON_1_Digest', pyxb.binding.datatypes.base64Binary)
+    __Digest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Digest'), 'Digest', '__httpwww_w3_orgnsws_policy_CTD_ANON__Digest', pyxb.binding.datatypes.base64Binary)
     
     Digest = property(__Digest.value, __Digest.set, None, None)
 
@@ -86,31 +128,13 @@ class CTD_ANON_1 (pyxb.binding.basis.complexTypeDefinition):
         
     }
     _AttributeMap = {
-        __DigestAlgorithm.name() : __DigestAlgorithm,
         __URI.name() : __URI,
+        __DigestAlgorithm.name() : __DigestAlgorithm,
         __Digest.name() : __Digest
     }
 
 
 
-# Complex type CTD_ANON_2 with content type SIMPLE
-class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.anyURI
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyURI
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-
-
-
 # Complex type OperatorContentType with content type ELEMENT_ONLY
 class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
@@ -119,11 +143,11 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'OperatorContentType')
     # Base type is pyxb.binding.datatypes.anyType
     
-    # Element {http://www.w3.org/ns/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_orgnsws_policy_OperatorContentType_httpwww_w3_orgnsws_policyPolicyReference', True)
+    # Element {http://www.w3.org/ns/ws-policy}All uses Python identifier All
+    __All = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'All'), 'All', '__httpwww_w3_orgnsws_policy_OperatorContentType_httpwww_w3_orgnsws_policyAll', True)
 
     
-    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
+    All = property(__All.value, __All.set, None, None)
 
     
     # Element {http://www.w3.org/ns/ws-policy}ExactlyOne uses Python identifier ExactlyOne
@@ -140,19 +164,19 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     Policy = property(__Policy.value, __Policy.set, None, None)
 
     
-    # Element {http://www.w3.org/ns/ws-policy}All uses Python identifier All
-    __All = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'All'), 'All', '__httpwww_w3_orgnsws_policy_OperatorContentType_httpwww_w3_orgnsws_policyAll', True)
+    # Element {http://www.w3.org/ns/ws-policy}PolicyReference uses Python identifier PolicyReference
+    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_orgnsws_policy_OperatorContentType_httpwww_w3_orgnsws_policyPolicyReference', True)
 
     
-    All = property(__All.value, __All.set, None, None)
+    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
 
     _HasWildcardElement = True
 
     _ElementMap = {
-        __PolicyReference.name() : __PolicyReference,
+        __All.name() : __All,
         __ExactlyOne.name() : __ExactlyOne,
         __Policy.name() : __Policy,
-        __All.name() : __All
+        __PolicyReference.name() : __PolicyReference
     }
     _AttributeMap = {
         
@@ -160,24 +184,24 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'OperatorContentType', OperatorContentType)
 
 
-# Complex type CTD_ANON_3 with content type ELEMENT_ONLY
-class CTD_ANON_3 (OperatorContentType):
+# Complex type CTD_ANON_2 with content type ELEMENT_ONLY
+class CTD_ANON_2 (OperatorContentType):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
     # Base type is OperatorContentType
     
-    # Element PolicyReference ({http://www.w3.org/ns/ws-policy}PolicyReference) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
+    # Element All ({http://www.w3.org/ns/ws-policy}All) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
     
     # Element ExactlyOne ({http://www.w3.org/ns/ws-policy}ExactlyOne) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
     
     # Element Policy ({http://www.w3.org/ns/ws-policy}Policy) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
     
-    # Element All ({http://www.w3.org/ns/ws-policy}All) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
+    # Element PolicyReference ({http://www.w3.org/ns/ws-policy}PolicyReference) inherited from {http://www.w3.org/ns/ws-policy}OperatorContentType
     
     # Attribute Name uses Python identifier Name
-    __Name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Name'), 'Name', '__httpwww_w3_orgnsws_policy_CTD_ANON_3_Name', pyxb.binding.datatypes.anyURI)
+    __Name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Name'), 'Name', '__httpwww_w3_orgnsws_policy_CTD_ANON_2_Name', pyxb.binding.datatypes.anyURI)
     
     Name = property(__Name.value, __Name.set, None, None)
 
@@ -195,15 +219,33 @@ class CTD_ANON_3 (OperatorContentType):
 
 
 
-# Complex type CTD_ANON_4 with content type ELEMENT_ONLY
+# Complex type CTD_ANON_3 with content type ELEMENT_ONLY
+class CTD_ANON_3 (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = None
+    # Base type is pyxb.binding.datatypes.anyType
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+
+
+
+# Complex type CTD_ANON_4 with content type SIMPLE
 class CTD_ANON_4 (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _TypeDefinition = pyxb.binding.datatypes.anyURI
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyType
+    # Base type is pyxb.binding.datatypes.anyURI
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-    _HasWildcardElement = True
 
     _ElementMap = {
         
@@ -214,137 +256,87 @@ class CTD_ANON_4 (pyxb.binding.basis.complexTypeDefinition):
 
 
 
-# Complex type CTD_ANON_5 with content type ELEMENT_ONLY
-class CTD_ANON_5 (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = None
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Element {http://www.w3.org/ns/ws-policy}AppliesTo uses Python identifier AppliesTo
-    __AppliesTo = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_orgnsws_policy_CTD_ANON_5_httpwww_w3_orgnsws_policyAppliesTo', False)
+PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON)
+Namespace.addCategoryObject('elementBinding', PolicyAttachment.name().localName(), PolicyAttachment)
 
-    
-    AppliesTo = property(__AppliesTo.value, __AppliesTo.set, None, None)
-
-    
-    # Element {http://www.w3.org/ns/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_orgnsws_policy_CTD_ANON_5_httpwww_w3_orgnsws_policyPolicyReference', True)
-
-    
-    PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
-
-    
-    # Element {http://www.w3.org/ns/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_orgnsws_policy_CTD_ANON_5_httpwww_w3_orgnsws_policyPolicy', True)
-
-    
-    Policy = property(__Policy.value, __Policy.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        __AppliesTo.name() : __AppliesTo,
-        __PolicyReference.name() : __PolicyReference,
-        __Policy.name() : __Policy
-    }
-    _AttributeMap = {
-        
-    }
-
-
-
-PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_1)
+PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_)
 Namespace.addCategoryObject('elementBinding', PolicyReference.name().localName(), PolicyReference)
 
-URI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'URI'), CTD_ANON_2)
-Namespace.addCategoryObject('elementBinding', URI.name().localName(), URI)
+AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_3)
+Namespace.addCategoryObject('elementBinding', AppliesTo.name().localName(), AppliesTo)
 
 ExactlyOne = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType)
 Namespace.addCategoryObject('elementBinding', ExactlyOne.name().localName(), ExactlyOne)
 
-Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3)
-Namespace.addCategoryObject('elementBinding', Policy.name().localName(), Policy)
-
 All = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType)
 Namespace.addCategoryObject('elementBinding', All.name().localName(), All)
 
-PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON_5)
-Namespace.addCategoryObject('elementBinding', PolicyAttachment.name().localName(), PolicyAttachment)
+URI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'URI'), CTD_ANON_4)
+Namespace.addCategoryObject('elementBinding', URI.name().localName(), URI)
 
-AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_4)
-Namespace.addCategoryObject('elementBinding', AppliesTo.name().localName(), AppliesTo)
-
-
-CTD_ANON_1._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)),
-    ])
-})
+Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_2)
+Namespace.addCategoryObject('elementBinding', Policy.name().localName(), Policy)
 
 
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_1, scope=OperatorContentType))
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_2, scope=CTD_ANON))
+
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_3, scope=CTD_ANON))
+
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_, scope=CTD_ANON))
+CTD_ANON._GroupModel_ = pyxb.binding.content.GroupChoice(
+    pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1)
+    )
+CTD_ANON._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_, min_occurs=1, max_occurs=None),
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy')), min_occurs=0L, max_occurs=None)
+    )
+CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel, min_occurs=1, max_occurs=1)
+
+
+CTD_ANON_._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+CTD_ANON_._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_._GroupModel, min_occurs=1, max_occurs=1)
+
+
+
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, scope=OperatorContentType))
 
 OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, scope=OperatorContentType))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=OperatorContentType))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_2, scope=OperatorContentType))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, scope=OperatorContentType))
-OperatorContentType._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy'))),
-    ])
-})
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_, scope=OperatorContentType))
+OperatorContentType._GroupModel_ = pyxb.binding.content.GroupChoice(
+    pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy')), min_occurs=1, max_occurs=1)
+    )
+OperatorContentType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(OperatorContentType._GroupModel_, min_occurs=0L, max_occurs=None)
+    )
+OperatorContentType._ContentModel = pyxb.binding.content.ParticleModel(OperatorContentType._GroupModel, min_occurs=1, max_occurs=1)
 
 
-CTD_ANON_3._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, element_use=CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All'))),
-        pyxb.binding.content.ContentModelTransition(next_state=1, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy'))),
-    ])
-})
+CTD_ANON_2._GroupModel_ = pyxb.binding.content.GroupChoice(
+    pyxb.binding.content.ParticleModel(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy')), min_occurs=1, max_occurs=1)
+    )
+CTD_ANON_2._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(CTD_ANON_2._GroupModel_, min_occurs=0L, max_occurs=None)
+    )
+CTD_ANON_2._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_2._GroupModel, min_occurs=1, max_occurs=1)
 
 
-CTD_ANON_4._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=False, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)),
-    ])
-    , 2 : pyxb.binding.content.ContentModelState(state=2, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)),
-    ])
-})
-
-
-
-CTD_ANON_5._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_4, scope=CTD_ANON_5))
-
-CTD_ANON_5._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON_1, scope=CTD_ANON_5))
-
-CTD_ANON_5._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=CTD_ANON_5))
-CTD_ANON_5._ContentModel = pyxb.binding.content.ContentModel(state_map = {
-      1 : pyxb.binding.content.ContentModelState(state=1, is_final=False, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=2, element_use=CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'))),
-    ])
-    , 2 : pyxb.binding.content.ContentModelState(state=2, is_final=False, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=4, element_use=CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'))),
-        pyxb.binding.content.ContentModelTransition(next_state=4, element_use=CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy'))),
-    ])
-    , 3 : pyxb.binding.content.ContentModelState(state=3, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=3, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy'))),
-    ])
-    , 4 : pyxb.binding.content.ContentModelState(state=4, is_final=True, transitions=[
-        pyxb.binding.content.ContentModelTransition(next_state=4, element_use=CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'))),
-        pyxb.binding.content.ContentModelTransition(next_state=4, element_use=CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy'))),
-        pyxb.binding.content.ContentModelTransition(next_state=3, term=pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/ns/ws-policy'))),
-    ])
-})
+CTD_ANON_3._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=1, max_occurs=None)
+    )
+CTD_ANON_3._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON_3._GroupModel, min_occurs=1, max_occurs=1)
